@@ -1,7 +1,7 @@
 #include <GeographicLib/Geodesic.hpp>
 #include <GeographicLib/Rhumb.hpp>
 
-extern "C" double rhumb_inverse(double lon1, double lat1, double lon2, double lat2)
+extern "C" double rhumb_inverse(double lat1, double lon1, double lat2, double lon2)
 {
         static const GeographicLib::Rhumb &rhumb = GeographicLib::Rhumb::WGS84();
         double azimuth;
